@@ -317,3 +317,20 @@ MultitableResult <- setClass("MultitableResult", contains="namedList")
 TabBookResult <- setClass("TabBookResult", contains="namedList")
 
 SearchResults <- setClass("SearchResults", contains="namedList")
+
+#' @rdname geo
+setClass("CrunchGeography", contains="namedList")
+#' @rdname geo
+#' @export
+CrunchGeography <- function (..., data=NULL) {
+    if (is.null(data)) {
+        data <- list(...)
+    }
+    return(new("CrunchGeography", data))
+}
+
+#' @rdname geo
+#' @export Geodata
+Geodata <- setClass("Geodata", contains="ShojiEntity")
+GeoCatalog <- setClass("GeoCatalog", contains="ShojiCatalog")
+
