@@ -22,9 +22,13 @@
 #' \code{FALSE}) and 'prefix_subvariables' for SPSS format: whether to include
 #' the array variable's name in each of its subvariables varlabels (default:
 #' \code{FALSE}).
+#' @param x (for write.csv) CrunchDataset, which may have been subsetted with a filter
+#' expression on the rows and a selection of variables on the columns.
+#' 
+#' @aliases write.csv
+#' 
 #' @return Invisibly, \code{file}.
 #' @export
-#' @importFrom utils download.file
 exportDataset <- function (dataset, file, format=c("csv", "spss"),
                            categorical=c("name", "id"), na=NULL,
                            varlabel=c("name", "description"), ...) {
@@ -54,7 +58,7 @@ exportDataset <- function (dataset, file, format=c("csv", "spss"),
     }
 
     result <- crPOST(export_url, body=toJSON(body))
-    download.file(result, file, quiet=TRUE, method="curl") ## Note outside of auth. Ok because file is in s3 with token
+    file <- crDownload(result, file)
     invisible(file)
 }
 
@@ -86,4 +90,4 @@ variablesFilter <- function (dataset) {
 
 #' @rdname exportDataset
 #' @export
-setMethod("write.csv", "CrunchDataset", function (...) exportDataset(..., format="csv"))
+setMethod("write.csv", "CrunchDataset", function (x, ...) exportDataset(x, ..., format="csv"))
