@@ -111,3 +111,7 @@ shojiURL <- function (x, collection=c("catalogs", "views", "fragments", "orders"
     }
     return(out)
 }
+
+wrapEntity <- function (..., body=list(...)) {
+    list(element="shoji:entity", body=body)
+}
