@@ -43,6 +43,32 @@ setMethod("notes", "CrunchVariable", function (x) tuple(x)$notes)
 setMethod("notes<-", "CrunchVariable",
     function (x, value) setTupleSlot(x, "notes", value %||% ""))
 
+#' @rdname describe
+#' @export
+setMethod("digits", "CrunchVariable", function (x) {
+    var_entity <- entity(x)
+    return(var_entity@body$format$data$digits)
+})
+#' @rdname describe
+#' @export
+setMethod("digits<-", "NumericVariable", function (x, value) {
+    if (!is.numeric(value) || !is.whole(value)) {
+        halt("digit specifications should be an integer")
+    }
+    if (value < 0 | value > 16) {
+        halt("digit specifications should be between 0 and 16")
+    }
+
+    frmt <- wrapEntity("format" = list("data" = list("digits" = value)))
+    crPATCH(self(x), body=toJSON(frmt))
+    invisible(x)
+})
+#' @rdname describe
+#' @export
+setMethod("digits<-", "CrunchVariable", function (x, value) {
+    halt("digit specifications can only be set for numeric variables")
+})
+
 #' Get and set Categories on Variables
 #'
 #' @param x a Variable
