@@ -2,7 +2,8 @@ context("Add a variable to a dataset")
 
 test_that("toVariable parses R numerics", {
     expect_identical(toVariable(2L:4L, name="Numbers!", alias="num"),
-        structure(list(values=2L:4L, type="numeric", name="Numbers!", alias="num"), class="VariableDefinition"))
+        structure(list(values=2L:4L, type="numeric", name="Numbers!",
+                       alias="num"), class="VariableDefinition"))
     expect_equivalent(toVariable(2L:4L, name="Numbers!", alias="num"),
         list(values=2L:4L, type="numeric", name="Numbers!", alias="num"))
 })
@@ -19,6 +20,14 @@ test_that("toVariable parses factors", {
             list(id=-1L, name="No Data", numeric_value=NULL, missing=TRUE)
         ))) ## unclear why these aren't identical
 })
+test_that("toVariable parses AsIses", {
+    expect_identical(toVariable(I(1:5)),
+                     structure(list(values=1L:5L, type="numeric"),
+                               class="VariableDefinition"))
+    expect_identical(toVariable(I(letters[1:3])),
+                     structure(list(values=c("a", "b", "c"), type="text"),
+                               class="VariableDefinition"))
+})
 
 test_that("toVariable handles duplicate factor levels", {
     ## Duplicate factor labels were deprecated and are forbidden in the `factor`
@@ -37,7 +46,13 @@ test_that("toVariable handles duplicate factor levels", {
             ))),
         "Duplicate factor levels given: disambiguating them in translation to Categorical type")
 })
-
+test_that("categoriesFromLevels parses levels correctly", {
+    expect_identical(categoriesFromLevels(levels(iris$Species)),
+        list(list(id = 1L, name = "setosa", numeric_value = 1L, missing = FALSE),
+             list(id = 2L, name = "versicolor", numeric_value = 2L, missing = FALSE), 
+             list(id = 3L, name = "virginica", numeric_value = 3L, missing = FALSE))
+      )
+})
 test_that("toVariable parses R Date class", {
     expect_equivalent(toVariable(as.Date(c("2014-12-16", "2014-12-17"))),
         list(values=c("2014-12-16", "2014-12-17"), type="datetime",
