@@ -1,6 +1,6 @@
 context("Appending subsets")
 
-with_mock_HTTP({
+with_mock_crunch({
     ds1 <- loadDataset("test ds")
     ds2 <- loadDataset("ECON.sav")
     test_that("If no filtering, 'where' and 'filter' are omitted", {
