@@ -34,6 +34,9 @@ with_mock_crunch({
 
     test_that("category slicers", {
         expect_true(is.categories(cats[1]))
+        expect_equal(cats[c("Female", "Male")], cats[c(2, 1)])
+        expect_error(cats[c("Female", "Male", "not a category")],
+                     "subscript out of bounds: not a category")
         expect_error(cats[c(1, 2, 5)],
             "subscript out of bounds: 5")
         expect_error(cats[c(1, 2, 98, 99)],
@@ -230,7 +233,7 @@ with_mock_crunch({
     test_that("c(Categories, Categories)", {
         expect_true(is.categories(c(cats, cats2)))
     })
-    
+
     test_that("changeCategoryID errors with bad inputs", {
         expect_error(ds$birthyr <- changeCategoryID(ds$birthyr, 1, 6),
                      "The variable Birth Year doesn't have categories.")
@@ -246,7 +249,7 @@ with_mock_crunch({
                      "to should be a single numeric")
         expect_error(ds$gender <- changeCategoryID(ds$gender, 8, 9),
                      "No category with id 8")
-        expect_PATCH(changeCategoryID(ds$gender, 2, 6), 
+        expect_PATCH(changeCategoryID(ds$gender, 2, 6),
                      'https://app.crunch.io/api/datasets/1/variables/gender/',
                      '{"categories":[{"id":1,"missing":false,"name":"Male","numeric_value":1},{"id":2,"missing":false,"name":"__TO_DELETE__","numeric_value":2},{"id":-1,"missing":true,"name":"No Data","numeric_value":null}]}')
     })
@@ -347,7 +350,7 @@ with_test_authentication({
                 c(1, 2, -1))
             orig_vector <- as.vector(ds$v4f)
             expect_equal(as.vector(ds$v4f[1:4], mode="id"), c(1, 2, 1, 2))
-            
+
             ds$v4f <- changeCategoryID(ds$v4f, 2, 6)
             expect_identical(names(categories(ds$v4f)),
                 c("B", "C", "No Data"))
@@ -359,6 +362,7 @@ with_test_authentication({
 
         test_that("Can changeCategoryID for array variables", {
             ds_apidocs <- newDatasetFromFixture("apidocs")
+            # categorical array variables
             expect_identical(names(categories(ds_apidocs$petloc)),
                              c("Cat", "Dog", "Bird", "Skipped", "Not Asked"))
             expect_equal(ids(categories(ds_apidocs$petloc)),
@@ -369,7 +373,6 @@ with_test_authentication({
                          data.frame(petloc_home=c(8, 2, 9, 9),
                                     petloc_work=c(9, 3, 3, 2)))
 
-            
             ds_apidocs$petloc <- changeCategoryID(ds_apidocs$petloc, 2, 6)
             expect_identical(names(categories(ds_apidocs$petloc)),
                              c("Cat", "Dog", "Bird", "Skipped", "Not Asked"))
@@ -380,6 +383,18 @@ with_test_authentication({
             expect_equal(as.vector(ds_apidocs$petloc[1:4], mode="id"),
                          data.frame(petloc_home=c(8, 6, 9, 9),
                                     petloc_work=c(9, 3, 3, 6)))
+            # multiple response variables
+            orig_vector <- as.vector(ds_apidocs$allpets[[1]])
+            expect_equal(ids(categories(ds_apidocs$allpets)), c(2, 1, 9, 8))
+            expect_equal(names(categories(ds_apidocs$allpets)),
+                         c("not selected", "selected", "not asked", "skipped"))
+
+            ds_apidocs$allpets <- changeCategoryID(ds_apidocs$allpets, 2, 6)
+            ds_apidocs$allpets <- changeCategoryID(ds_apidocs$allpets, 9, 7)
+            expect_equal(as.vector(ds_apidocs$allpets[[1]]), orig_vector)
+            expect_equal(ids(categories(ds_apidocs$allpets)), c(6, 1, 7, 8))
+            expect_equal(names(categories(ds_apidocs$allpets)),
+                         c("not selected", "selected", "not asked", "skipped"))
         })
     })
 
