@@ -1,6 +1,6 @@
 context("Combine categories")
 
-with_mock_HTTP({
+with_mock_crunch({
     ds <- loadDataset("test ds")
 
     both <- VariableDefinition(
