@@ -9,6 +9,8 @@ with_mock_crunch({
         expect_identical(datasetReference(ds$gender), ds_url)
         expect_identical(datasetReference(ds$mymrset$subvar1), ds_url)
         expect_identical(datasetReference(ds$gender == "Male"), ds_url)
+        expect_identical(datasetReference(multitables(ds)), ds_url)
+        expect_identical(datasetReference(multitables(ds)[[1]]), ds_url)
         expect_null(datasetReference(1))
         expect_identical(datasetReference("https://app.crunch.io/api/datasets/1/variables/mymrset/subvariables/subvar1"), ds_url)
     })
