@@ -29,15 +29,16 @@ with_mock_crunch({
         expect_is(hidden(varcat), "VariableCatalog")
         expect_identical(urls(active(varcat)),
             c("https://app.crunch.io/api/datasets/1/variables/gender/",
+            "https://app.crunch.io/api/datasets/1/variables/location/",
             "https://app.crunch.io/api/datasets/1/variables/mymrset/",
             "https://app.crunch.io/api/datasets/1/variables/textVar/",
             "https://app.crunch.io/api/datasets/1/variables/starttime/",
             "https://app.crunch.io/api/datasets/1/variables/catarray/"))
-        expect_length(active(varcat), 5)
+        expect_length(active(varcat), 6)
         expect_identical(urls(hidden(varcat)),
             "https://app.crunch.io/api/datasets/1/variables/birthyr/")
         expect_length(hidden(varcat), 1)
-        expect_length(varcat, 6)
+        expect_length(varcat, 7)
         expect_identical(active(hidden(varcat)), hidden(active(varcat)))
     })
 
@@ -70,33 +71,34 @@ with_mock_crunch({
     })
 
     test_that("attribute getters", {
-        expect_identical(names(varcat)[1:3],
-            c("Birth Year", "Gender", "mymrset"))
+        expect_identical(names(varcat)[1:4],
+            c("Birth Year", "Gender", "Categorical Location", "mymrset"))
         expect_identical(aliases(varcat)[1:2], c("birthyr", "gender"))
-        expect_identical(types(varcat)[1:3],
-            c("numeric", "categorical", "multiple_response"))
-        expect_identical(descriptions(varcat[1:3]),
-            c(NA, "Gender", "Please select all that apply"))
-        expect_identical(notes(varcat[1:3]),
-            c("Asked instead of age", "", ""))
+        expect_identical(types(varcat)[1:4],
+            c("numeric", "categorical", "categorical", "multiple_response"))
+        expect_identical(descriptions(varcat[1:4]),
+            c(NA, "Gender", "Location test", "Please select all that apply"))
+        expect_identical(notes(varcat[1:4]),
+            c("Asked instead of age", "", "", ""))
     })
 
     test_that("attribute setters", {
-        expect_PATCH(names(varcat)[1:3] <- c("Year of birth", "Gender", "Start time"),
+        expect_PATCH(names(varcat)[1:4] <- c("Year of birth", "Gender", "Loc", "Start time"),
             "https://app.crunch.io/api/datasets/1/variables/",
             '{"https://app.crunch.io/api/datasets/1/variables/birthyr/":{"name":"Year of birth"},',
+            '"https://app.crunch.io/api/datasets/1/variables/location/":{"name":"Loc"},',
             '"https://app.crunch.io/api/datasets/1/variables/mymrset/":{"name":"Start time"}}')
-        expect_PATCH(notes(varcat)[1:3] <- c("Asked instead of age", "", "ms"),
+        expect_PATCH(notes(varcat)[1:4] <- c("Asked instead of age", "", "", "ms"),
             "https://app.crunch.io/api/datasets/1/variables/",
             '{"https://app.crunch.io/api/datasets/1/variables/mymrset/":{"notes":"ms"}}')
     })
 
     test_that("show method", {
-        expect_output(varcat[1:3],
+        expect_output(varcat[1:4],
             get_output(data.frame(
-                alias=c("birthyr", "gender", "mymrset"),
-                name=c("Birth Year", "Gender", "mymrset"),
-                type=c("numeric", "categorical", "multiple_response")
+                alias=c("birthyr", "gender", "location", "mymrset"),
+                name=c("Birth Year", "Gender", "Categorical Location", "mymrset"),
+                type=c("numeric", "categorical", "categorical", "multiple_response")
             )))
     })
 })
